@@ -1,17 +1,15 @@
-use std::io;
-use std::io::ErrorKind;
+use std::{io, io::ErrorKind};
 
-use async_graphql::http::MultipartOptions;
-use async_graphql::{BatchRequest, ObjectType, Schema, SubscriptionType};
+use async_graphql::{http::MultipartOptions, BatchRequest, ObjectType, Schema, SubscriptionType};
 use futures_util::TryStreamExt;
-use warp::reply::Response as WarpResponse;
-use warp::{Buf, Filter, Rejection, Reply};
+use warp::{reply::Response as WarpResponse, Buf, Filter, Rejection, Reply};
 
 use crate::GraphQLBadRequest;
 
 /// GraphQL batch request filter
 ///
-/// It outputs a tuple containing the `async_graphql::Schema` and `async_graphql::BatchRequest`.
+/// It outputs a tuple containing the `async_graphql::Schema` and
+/// `async_graphql::BatchRequest`.
 pub fn graphql_batch<Query, Mutation, Subscription>(
     schema: Schema<Query, Mutation, Subscription>,
 ) -> impl Filter<Extract = ((Schema<Query, Mutation, Subscription>, BatchRequest),), Error = Rejection>
@@ -24,7 +22,8 @@ where
     graphql_batch_opts(schema, Default::default())
 }
 
-/// Similar to graphql_batch, but you can set the options with :`async_graphql::MultipartOptions`.
+/// Similar to graphql_batch, but you can set the options with
+/// :`async_graphql::MultipartOptions`.
 pub fn graphql_batch_opts<Query, Mutation, Subscription>(
     schema: Schema<Query, Mutation, Subscription>,
     opts: MultipartOptions,
